All Classes
-
All Classes Interface Summary Class Summary Enum Summary Exception Summary Class Description AccessTokenListener ApiClient ApiClient class.ApiException ApiException class.ApiKeyAuth ApiKeyAuth class.ApiResponse<T> API response returned by API call.Authentication AuthenticationMethod A value that most closely matches the technique your application used to authenticate the recipient / signer.Configuration Configuration class.CreateInstanceRequestBody Request body containing properties that will be used to create instance..CreateInstanceRequestBodyRecipients CreateInstanceRequestBodyRecipients.FormInstanceManagementApi FormInstanceManagementApi class.FormManagementApi FormManagementApi class.HttpBasicAuth HttpBasicAuth class.HttpError An error occurred while processing a request.HttpSuccess A simple response indicating success when no extra data is needed.InstanceRecipientStatus The current status of the instance for the recipientInstanceSource The method through which form instance is created.InstanceStatus The status of Web Form Instance.JSON JSON Class.JWTUtils JWTUtils class.OAuth OAuth class.OAuth.Account Account model with the below properties.OAuth.Link Link model with the below properties.OAuth.OAuthToken OAuthToken model with the following properties.OAuth.Organization Organization model with the below properties.OAuth.UserInfo UserInfo model with the below properties.OAuthFlow enum.Pair Pair class.PhoneNumber Phone number of the user..RFC3339DateFormat RFC3339DateFormat class.SendOption Specifies the delivery behavior of the web form.Source The method through which form instance is created.StringUtil StringUtil class.Tags List of tags provided by the user with each request.TemplateProperties Information about a DocuSign template that will be used to seed a web form..UpdateInstanceRequestBody Request body containing properties that needs to be updated..UserFilter Filter which forms are returnedWebForm An object that fully describes an instance of a form.WebFormAdmType Type used at ADM model as ComponentType decorator.WebFormComponent Each component type contains additional properties.WebFormComponentsMap The components map for the web form.WebFormComponentType Type of components used in the web formWebFormContent Container for the components map used during configuration and data collection.WebFormInstance An object that contains the Web Form Instance required to render it and its metadata such as created by, created time.WebFormInstanceEnvelopes WebFormInstanceEnvelopes.WebFormInstanceList A list of web form instance items..WebFormInstanceMetadata Web Form Instance metadata containing information like created by, created time, etc..WebFormInstanceRecipients WebFormInstanceRecipients.WebFormMetadata Form metadata.WebFormProperties General information about the web form that is consistent across versions.WebFormPublishedNames A collection of the published component name and its corresponding type.WebFormSource The source from which the web form is created.WebFormState The state of the form contentWebFormSummary An object that summarizes an instance of a form that can be used to display a listing.WebFormSummaryList A list of web form summary items..WebFormType The field indicates webform type.WebFormUserInfo Information about a DocuSign system user.WebFormValues Key-value pairs (where key is the component name and value is the form value) used to create a form instance.