Class FormManagementApi


  • public class FormManagementApi
    extends Object
    FormManagementApi class.
    • Constructor Detail

      • FormManagementApi

        public FormManagementApi()
        FormManagementApi.
      • FormManagementApi

        public FormManagementApi​(ApiClient apiClient)
        FormManagementApi.
    • Method Detail

      • getApiClient

        public ApiClient getApiClient()
        getApiClient Method.
        Returns:
        ApiClient
      • setApiClient

        public void setApiClient​(ApiClient apiClient)
        setApiClient Method.
      • getForm

        public WebForm getForm​(String accountId,
                               String formId)
                        throws ApiException
        Get Form. Retrieves form information filter by form id and state. The `state` parameter is optional and can accept value from `draft, active`.
        Parameters:
        accountId - Account identifier in which the web form resides (required)
        formId - Unique identifier for a web form that is consistent for it's lifetime (required)
        Returns:
        WebForm
        Throws:
        ApiException
      • getForm

        public WebForm getForm​(String accountId,
                               String formId,
                               FormManagementApi.GetFormOptions options)
                        throws ApiException
        Get Form. Retrieves form information filter by form id and state. The `state` parameter is optional and can accept value from `draft, active`.
        Parameters:
        accountId - Account identifier in which the web form resides (required)
        formId - Unique identifier for a web form that is consistent for it's lifetime (required)
        options - for modifying the method behavior.
        Returns:
        WebForm
        Throws:
        ApiException - if fails to make API call
      • getFormWithHttpInfo

        public ApiResponse<WebForm> getFormWithHttpInfo​(String accountId,
                                                        String formId,
                                                        FormManagementApi.GetFormOptions options)
                                                 throws ApiException
        Get Form Retrieves form information filter by form id and state. The `state` parameter is optional and can accept value from `draft, active`.
        Parameters:
        accountId - Account identifier in which the web form resides (required)
        formId - Unique identifier for a web form that is consistent for it's lifetime (required)
        options - for modifying the method behavior.
        Returns:
        WebForm
        Throws:
        ApiException - if fails to make API call
      • listForms

        public WebFormSummaryList listForms​(String accountId)
                                     throws ApiException
        List Forms. List all the forms for the active user that can be in an active or draft state
        Parameters:
        accountId - Account identifier in which the webform resides (required)
        Returns:
        WebFormSummaryList
        Throws:
        ApiException
      • listForms

        public WebFormSummaryList listForms​(String accountId,
                                            FormManagementApi.ListFormsOptions options)
                                     throws ApiException
        List Forms. List all the forms for the active user that can be in an active or draft state
        Parameters:
        accountId - Account identifier in which the webform resides (required)
        options - for modifying the method behavior.
        Returns:
        WebFormSummaryList
        Throws:
        ApiException - if fails to make API call
      • listFormsWithHttpInfo

        public ApiResponse<WebFormSummaryList> listFormsWithHttpInfo​(String accountId,
                                                                     FormManagementApi.ListFormsOptions options)
                                                              throws ApiException
        List Forms List all the forms for the active user that can be in an active or draft state
        Parameters:
        accountId - Account identifier in which the webform resides (required)
        options - for modifying the method behavior.
        Returns:
        WebFormSummaryList
        Throws:
        ApiException - if fails to make API call