Uses of Class
com.docusign.webforms.client.ApiException
-
Packages that use ApiException Package Description com.docusign.webforms.api com.docusign.webforms.client com.docusign.webforms.client.auth -
-
Uses of ApiException in com.docusign.webforms.api
Methods in com.docusign.webforms.api that throw ApiException Modifier and Type Method Description WebFormInstanceFormInstanceManagementApi. createInstance(String accountId, String formId, CreateInstanceRequestBody createInstanceBody)Creates an instance of the web form.ApiResponse<WebFormInstance>FormInstanceManagementApi. createInstanceWithHttpInfo(String accountId, String formId, CreateInstanceRequestBody createInstanceBody)Creates an instance of the web form Creates an instance of the web form.WebFormFormManagementApi. getForm(String accountId, String formId)Get Form.WebFormFormManagementApi. getForm(String accountId, String formId, FormManagementApi.GetFormOptions options)Get Form.ApiResponse<WebForm>FormManagementApi. getFormWithHttpInfo(String accountId, String formId, FormManagementApi.GetFormOptions options)Get Form Retrieves form information filter by form id and state.WebFormInstanceFormInstanceManagementApi. getInstance(String accountId, String formId, String instanceId)Get form instance.ApiResponse<WebFormInstance>FormInstanceManagementApi. getInstanceWithHttpInfo(String accountId, String formId, String instanceId)Get form instance Retrieves instance information filter by instance idWebFormSummaryListFormManagementApi. listForms(String accountId)List Forms.WebFormSummaryListFormManagementApi. listForms(String accountId, FormManagementApi.ListFormsOptions options)List Forms.ApiResponse<WebFormSummaryList>FormManagementApi. listFormsWithHttpInfo(String accountId, FormManagementApi.ListFormsOptions options)List Forms List all the forms for the active user that can be in an active or draft stateWebFormInstanceListFormInstanceManagementApi. listInstances(String accountId, String formId)List instances.WebFormInstanceListFormInstanceManagementApi. listInstances(String accountId, String formId, FormInstanceManagementApi.ListInstancesOptions options)List instances.ApiResponse<WebFormInstanceList>FormInstanceManagementApi. listInstancesWithHttpInfo(String accountId, String formId, FormInstanceManagementApi.ListInstancesOptions options)List instances List all the instances of a web form in an account.WebFormInstanceFormInstanceManagementApi. refreshToken(String accountId, String formId, String instanceId)Refreshes the instance token.ApiResponse<WebFormInstance>FormInstanceManagementApi. refreshTokenWithHttpInfo(String accountId, String formId, String instanceId)Refreshes the instance token Generates new instance token for the existing Web Form Instance. -
Uses of ApiException in com.docusign.webforms.client
Methods in com.docusign.webforms.client that throw ApiException Modifier and Type Method Description voidApiClient. configureJWTAuthorizationFlow(String publicKeyFilename, String privateKeyFilename, String oAuthBasePath, String clientId, String userId, long expiresIn)Deprecated.As of release 2.7.0, replaced byApiClient.requestJWTUserToken(String, String, List, byte[], long)()} andApiClient.requestJWTApplicationToken(String, List, byte[], long)<T> TApiClient. deserialize(jakarta.ws.rs.core.Response response, jakarta.ws.rs.core.GenericType<T> returnType)Deserialize response body to Java object according to the Content-Type.FileApiClient. downloadFileFromResponse(jakarta.ws.rs.core.Response response)Download file from the given response.OAuth.OAuthTokenApiClient. generateAccessToken(String clientId, String clientSecret, String code)Helper method to configure the OAuth accessCode/implicit flow parameters.OAuth.UserInfoApiClient. getUserInfo(String accessToken)Gets the user info.<T> TApiClient. invokeAPI(String path, String method, List<Pair> queryParams, List<Pair> collectionQueryParams, Object body, Map<String,String> headerParams, Map<String,Object> formParams, String accept, String contentType, String[] authNames, jakarta.ws.rs.core.GenericType<T> returnType)Invoke API by sending HTTP request with the given options.OAuth.OAuthTokenApiClient. requestJWTApplicationToken(String clientId, List<String> scopes, byte[] rsaPrivateKey, long expiresIn)RESERVED FOR PARTNERS Request JWT Application Token.OAuth.OAuthTokenApiClient. requestJWTUserToken(String clientId, String userId, List<String> scopes, byte[] rsaPrivateKey, long expiresIn)Configures the current instance of ApiClient with a fresh OAuth JWT access token from Docusign.ObjectApiClient. serialize(Object obj, String contentType, Map<String,Object> formParams)Serialize the given Java object into string according the given Content-Type (only JSON is supported for now).jakarta.ws.rs.client.Entity<?>ApiClient. serialize(Object obj, Map<String,Object> formParams, String contentType)Serialize the given Java object into string entity according the given Content-Type (only JSON is supported for now). -
Uses of ApiException in com.docusign.webforms.client.auth
Methods in com.docusign.webforms.client.auth that throw ApiException Modifier and Type Method Description <T> TOAuth. deserialize(jakarta.ws.rs.core.Response response, jakarta.ws.rs.core.GenericType<T> returnType)Deserialize response body to Java object according to the Content-Type.OAuth.OAuthTokenOAuth. generateAccessToken()Helper method to configure the OAuth accessCode/implicit flow parameters.OAuth.OAuthTokenOAuth. requestJWTUserToken()Configures the current instance of ApiClient with a fresh OAuth JWT access token from DocuSign.jakarta.ws.rs.client.Entity<?>OAuth. serialize(Object obj, Map<String,Object> formParams, String contentType)Serialize the given Java object into string entity according the given Content-Type (only JSON is supported for now).voidOAuth. updateAccessToken()updateAccessToken method.
-