ApiResponse<WebFormInstance> |
FormInstanceManagementApi.createInstanceWithHttpInfo(String accountId,
String formId,
CreateInstanceRequestBody createInstanceBody) |
Creates an instance of the web form Creates an instance of the web form.
|
ApiResponse<WebForm> |
FormManagementApi.getFormWithHttpInfo(String accountId,
String formId,
FormManagementApi.GetFormOptions options) |
Get Form Retrieves form information filter by form id and state.
|
ApiResponse<WebFormInstance> |
FormInstanceManagementApi.getInstanceWithHttpInfo(String accountId,
String formId,
String instanceId) |
Get form instance Retrieves instance information filter by instance id
|
ApiResponse<WebFormSummaryList> |
FormManagementApi.listFormsWithHttpInfo(String accountId,
FormManagementApi.ListFormsOptions options) |
List Forms List all the forms for the active user that can be in an active or draft state
|
ApiResponse<WebFormInstanceList> |
FormInstanceManagementApi.listInstancesWithHttpInfo(String accountId,
String formId,
FormInstanceManagementApi.ListInstancesOptions options) |
List instances List all the instances of a web form in an account.
|
ApiResponse<WebFormInstance> |
FormInstanceManagementApi.refreshTokenWithHttpInfo(String accountId,
String formId,
String instanceId) |
Refreshes the instance token Generates new instance token for the existing Web Form Instance.
|