Package com.docusign.webforms.model
Enum AuthenticationMethod
- java.lang.Object
-
- java.lang.Enum<AuthenticationMethod>
-
- com.docusign.webforms.model.AuthenticationMethod
-
- All Implemented Interfaces:
Serializable,Comparable<AuthenticationMethod>
public enum AuthenticationMethod extends Enum<AuthenticationMethod>
A value that most closely matches the technique your application used to authenticate the recipient / signer.
-
-
Enum Constant Summary
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static AuthenticationMethodfromValue(String value)StringgetValue()StringtoString()static AuthenticationMethodvalueOf(String name)Returns the enum constant of this type with the specified name.static AuthenticationMethod[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
BIOMETRIC
public static final AuthenticationMethod BIOMETRIC
-
EMAIL
public static final AuthenticationMethod EMAIL
-
HTTPBASICAUTH
public static final AuthenticationMethod HTTPBASICAUTH
-
KERBEROS
public static final AuthenticationMethod KERBEROS
-
KNOWLEDGEBASEDAUTH
public static final AuthenticationMethod KNOWLEDGEBASEDAUTH
-
NONE
public static final AuthenticationMethod NONE
-
PAPERDOCUMENTS
public static final AuthenticationMethod PAPERDOCUMENTS
-
PASSWORD
public static final AuthenticationMethod PASSWORD
-
RSASECUREID
public static final AuthenticationMethod RSASECUREID
-
SINGLESIGNON_CASITEMINDER
public static final AuthenticationMethod SINGLESIGNON_CASITEMINDER
-
SINGLESIGNON_INFOCARD
public static final AuthenticationMethod SINGLESIGNON_INFOCARD
-
SINGLESIGNON_MICROSOFTACTIVEDIRECTORY
public static final AuthenticationMethod SINGLESIGNON_MICROSOFTACTIVEDIRECTORY
-
SINGLESIGNON_OTHER
public static final AuthenticationMethod SINGLESIGNON_OTHER
-
SINGLESIGNON_PASSPORT
public static final AuthenticationMethod SINGLESIGNON_PASSPORT
-
SINGLESIGNON_SAML
public static final AuthenticationMethod SINGLESIGNON_SAML
-
SMARTCARD
public static final AuthenticationMethod SMARTCARD
-
SSLMUTUALAUTH
public static final AuthenticationMethod SSLMUTUALAUTH
-
X509CERTIFICATE
public static final AuthenticationMethod X509CERTIFICATE
-
-
Method Detail
-
values
public static AuthenticationMethod[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (AuthenticationMethod c : AuthenticationMethod.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static AuthenticationMethod valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
public String getValue()
-
toString
public String toString()
- Overrides:
toStringin classEnum<AuthenticationMethod>
-
fromValue
public static AuthenticationMethod fromValue(String value)
-
-