Class CreateInstanceRequestBody

    • Constructor Detail

      • CreateInstanceRequestBody

        public CreateInstanceRequestBody()
    • Method Detail

      • getFormValues

        public Map<String,​Object> getFormValues()
        Key-value pairs (where key is the component name and value is the form value) used to create a form instance. For key of type TextBox, Email, Date, Select and RadioButtonGroup the value is of string type. For key of type Number, the value is of number type. For key of type of CheckboxGroup, the value is of type array of string..
        Returns:
        formValues
      • setFormValues

        public void setFormValues​(Map<String,​Object> formValues)
        setFormValues.
      • getClientUserId

        public String getClientUserId()
        Get clientUserId.
        Returns:
        clientUserId
      • setClientUserId

        public void setClientUserId​(String clientUserId)
        setClientUserId.
      • authenticationInstant

        public CreateInstanceRequestBody authenticationInstant​(String authenticationInstant)
        authenticationInstant.
        Returns:
        CreateInstanceRequestBody
      • getAuthenticationInstant

        public String getAuthenticationInstant()
        Get authenticationInstant.
        Returns:
        authenticationInstant
      • setAuthenticationInstant

        public void setAuthenticationInstant​(String authenticationInstant)
        setAuthenticationInstant.
      • getAuthenticationMethod

        public AuthenticationMethod getAuthenticationMethod()
        Get authenticationMethod.
        Returns:
        authenticationMethod
      • setAuthenticationMethod

        public void setAuthenticationMethod​(AuthenticationMethod authenticationMethod)
        setAuthenticationMethod.
      • getAssertionId

        public String getAssertionId()
        Get assertionId.
        Returns:
        assertionId
      • setAssertionId

        public void setAssertionId​(String assertionId)
        setAssertionId.
      • getSecurityDomain

        public String getSecurityDomain()
        Get securityDomain.
        Returns:
        securityDomain
      • setSecurityDomain

        public void setSecurityDomain​(String securityDomain)
        setSecurityDomain.
      • getReturnUrl

        public String getReturnUrl()
        Get returnUrl.
        Returns:
        returnUrl
      • setReturnUrl

        public void setReturnUrl​(String returnUrl)
        setReturnUrl.
      • getExpirationOffset

        public Integer getExpirationOffset()
        Get expirationOffset.
        Returns:
        expirationOffset
      • setExpirationOffset

        public void setExpirationOffset​(Integer expirationOffset)
        setExpirationOffset.
      • getSendOption

        public SendOption getSendOption()
        Get sendOption.
        Returns:
        sendOption
      • setSendOption

        public void setSendOption​(SendOption sendOption)
        setSendOption.
      • getBrandId

        public String getBrandId()
        Get brandId.
        Returns:
        brandId
      • setBrandId

        public void setBrandId​(String brandId)
        setBrandId.
      • getTags

        public List<String> getTags()
        List of tags provided by the user with each request. This field is optional..
        Returns:
        tags
      • setTags

        public void setTags​(List<String> tags)
        setTags.
      • equals

        public boolean equals​(Object o)
        Compares objects.
        Overrides:
        equals in class Object
        Returns:
        true or false depending on comparison result.
      • hashCode

        public int hashCode()
        Returns the HashCode.
        Overrides:
        hashCode in class Object
      • toString

        public String toString()
        Converts the given object to string.
        Overrides:
        toString in class Object