Package com.docusign.webforms.model
Enum InstanceSource
- java.lang.Object
-
- java.lang.Enum<InstanceSource>
-
- com.docusign.webforms.model.InstanceSource
-
- All Implemented Interfaces:
Serializable,Comparable<InstanceSource>
public enum InstanceSource extends Enum<InstanceSource>
The method through which form instance is created.
-
-
Enum Constant Summary
Enum Constants Enum Constant Description API_EMBEDDEDAPI_REMOTEPUBLIC_URLUI_REMOTEWORKFLOW
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static InstanceSourcefromValue(String value)StringgetValue()StringtoString()static InstanceSourcevalueOf(String name)Returns the enum constant of this type with the specified name.static InstanceSource[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
PUBLIC_URL
public static final InstanceSource PUBLIC_URL
-
API_EMBEDDED
public static final InstanceSource API_EMBEDDED
-
API_REMOTE
public static final InstanceSource API_REMOTE
-
UI_REMOTE
public static final InstanceSource UI_REMOTE
-
WORKFLOW
public static final InstanceSource WORKFLOW
-
-
Method Detail
-
values
public static InstanceSource[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (InstanceSource c : InstanceSource.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static InstanceSource valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
public String getValue()
-
toString
public String toString()
- Overrides:
toStringin classEnum<InstanceSource>
-
fromValue
public static InstanceSource fromValue(String value)
-
-