Enum Source

    • Enum Constant Detail

      • PUBLIC_URL

        public static final Source PUBLIC_URL
      • API_EMBEDDED

        public static final Source API_EMBEDDED
      • API_REMOTE

        public static final Source API_REMOTE
      • UI_REMOTE

        public static final Source UI_REMOTE
    • Method Detail

      • values

        public static Source[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (Source c : Source.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static Source valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • getValue

        public String getValue()
      • fromValue

        public static Source fromValue​(String value)