Package com.docusign.webforms.model
Class WebFormContent
- java.lang.Object
-
- com.docusign.webforms.model.WebFormContent
-
- All Implemented Interfaces:
Serializable
public class WebFormContent extends Object implements Serializable
Container for the components map used during configuration and data collection.- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description WebFormContent()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description WebFormContentaddTemplatesItem(TemplateProperties templatesItem)addTemplatesItem.WebFormContentbrandId(String brandId)brandId.WebFormContentcomponents(Map<String,Map<String,Object>> components)components.booleanequals(Object o)Compares objects.StringgetBrandId()Get brandId.Map<String,Map<String,Object>>getComponents()Key/value dictionary of components that represent the form.BooleangetIsStandalone()Get isStandalone.List<TemplateProperties>getTemplates()Optional template information that will be used to seed the form..inthashCode()Returns the HashCode.WebFormContentisStandalone(Boolean isStandalone)isStandalone.WebFormContentputComponentsItem(String key, Map<String,Object> componentsItem)putComponentsItem.voidsetBrandId(String brandId)setBrandId.voidsetComponents(Map<String,Map<String,Object>> components)setComponents.voidsetIsStandalone(Boolean isStandalone)setIsStandalone.voidsetTemplates(List<TemplateProperties> templates)setTemplates.WebFormContenttemplates(List<TemplateProperties> templates)templates.StringtoString()Converts the given object to string.
-
-
-
Method Detail
-
components
public WebFormContent components(Map<String,Map<String,Object>> components)
components.- Returns:
- WebFormContent
-
putComponentsItem
public WebFormContent putComponentsItem(String key, Map<String,Object> componentsItem)
putComponentsItem.- Returns:
- WebFormContent
-
getComponents
public Map<String,Map<String,Object>> getComponents()
Key/value dictionary of components that represent the form.- Returns:
- components
-
setComponents
public void setComponents(Map<String,Map<String,Object>> components)
setComponents.
-
isStandalone
public WebFormContent isStandalone(Boolean isStandalone)
isStandalone.- Returns:
- WebFormContent
-
getIsStandalone
public Boolean getIsStandalone()
Get isStandalone.- Returns:
- isStandalone
-
setIsStandalone
public void setIsStandalone(Boolean isStandalone)
setIsStandalone.
-
brandId
public WebFormContent brandId(String brandId)
brandId.- Returns:
- WebFormContent
-
getBrandId
public String getBrandId()
Get brandId.- Returns:
- brandId
-
setBrandId
public void setBrandId(String brandId)
setBrandId.
-
templates
public WebFormContent templates(List<TemplateProperties> templates)
templates.- Returns:
- WebFormContent
-
addTemplatesItem
public WebFormContent addTemplatesItem(TemplateProperties templatesItem)
addTemplatesItem.- Returns:
- WebFormContent
-
getTemplates
public List<TemplateProperties> getTemplates()
Optional template information that will be used to seed the form..- Returns:
- templates
-
setTemplates
public void setTemplates(List<TemplateProperties> templates)
setTemplates.
-
equals
public boolean equals(Object o)
Compares objects.
-
-