Package com.docusign.webforms.model
Class WebFormProperties
- java.lang.Object
-
- com.docusign.webforms.model.WebFormProperties
-
- All Implemented Interfaces:
Serializable
public class WebFormProperties extends Object implements Serializable
General information about the web form that is consistent across versions.- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description WebFormProperties()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description WebFormPropertiesallowSending(Boolean allowSending)allowSending.booleanequals(Object o)Compares objects.BooleangetIsPrivateAccess()Get isPrivateAccess.StringgetName()Get name.inthashCode()Returns the HashCode.BooleanisAllowSending()When this property is true, form can be used for remote signing..WebFormPropertiesisPrivateAccess(Boolean isPrivateAccess)isPrivateAccess.WebFormPropertiesname(String name)name.voidsetAllowSending(Boolean allowSending)setAllowSending.voidsetIsPrivateAccess(Boolean isPrivateAccess)setIsPrivateAccess.voidsetName(String name)setName.StringtoString()Converts the given object to string.
-
-
-
Method Detail
-
name
public WebFormProperties name(String name)
name.- Returns:
- WebFormProperties
-
getName
public String getName()
Get name.- Returns:
- name
-
setName
public void setName(String name)
setName.
-
isPrivateAccess
public WebFormProperties isPrivateAccess(Boolean isPrivateAccess)
isPrivateAccess.- Returns:
- WebFormProperties
-
getIsPrivateAccess
public Boolean getIsPrivateAccess()
Get isPrivateAccess.- Returns:
- isPrivateAccess
-
setIsPrivateAccess
public void setIsPrivateAccess(Boolean isPrivateAccess)
setIsPrivateAccess.
-
allowSending
public WebFormProperties allowSending(Boolean allowSending)
allowSending.- Returns:
- WebFormProperties
-
isAllowSending
public Boolean isAllowSending()
When this property is true, form can be used for remote signing..- Returns:
- allowSending
-
setAllowSending
public void setAllowSending(Boolean allowSending)
setAllowSending.
-
equals
public boolean equals(Object o)
Compares objects.
-
-