Package com.docusign.webforms.model
Class WebFormPublishedNames
- java.lang.Object
-
- java.util.AbstractMap<K,V>
-
- java.util.HashMap<String,String>
-
- com.docusign.webforms.model.WebFormPublishedNames
-
- All Implemented Interfaces:
Serializable,Cloneable,Map<String,String>
public class WebFormPublishedNames extends HashMap<String,String>
A collection of the published component name and its corresponding type.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K extends Object,V extends Object>, AbstractMap.SimpleImmutableEntry<K extends Object,V extends Object>
-
-
Constructor Summary
Constructors Constructor Description WebFormPublishedNames()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object o)Compares objects.inthashCode()Returns the HashCode.StringtoString()Converts the given object to string.-
Methods inherited from class java.util.HashMap
clear, clone, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, forEach, get, getOrDefault, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
-