Package com.docusign.webforms.model
Enum WebFormSource
- java.lang.Object
-
- java.lang.Enum<WebFormSource>
-
- com.docusign.webforms.model.WebFormSource
-
- All Implemented Interfaces:
Serializable,Comparable<WebFormSource>
public enum WebFormSource extends Enum<WebFormSource>
The source from which the web form is created.
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static WebFormSourcefromValue(String value)StringgetValue()StringtoString()static WebFormSourcevalueOf(String name)Returns the enum constant of this type with the specified name.static WebFormSource[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
TEMPLATES
public static final WebFormSource TEMPLATES
-
BLANK
public static final WebFormSource BLANK
-
FORM
public static final WebFormSource FORM
-
-
Method Detail
-
values
public static WebFormSource[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (WebFormSource c : WebFormSource.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static WebFormSource valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
public String getValue()
-
toString
public String toString()
- Overrides:
toStringin classEnum<WebFormSource>
-
fromValue
public static WebFormSource fromValue(String value)
-
-