Uses of Class
com.docusign.webforms.model.AuthenticationMethod
-
Packages that use AuthenticationMethod Package Description com.docusign.webforms.model -
-
Uses of AuthenticationMethod in com.docusign.webforms.model
Methods in com.docusign.webforms.model that return AuthenticationMethod Modifier and Type Method Description static AuthenticationMethodAuthenticationMethod. fromValue(String value)AuthenticationMethodCreateInstanceRequestBody. getAuthenticationMethod()Get authenticationMethod.static AuthenticationMethodAuthenticationMethod. valueOf(String name)Returns the enum constant of this type with the specified name.static AuthenticationMethod[]AuthenticationMethod. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.docusign.webforms.model with parameters of type AuthenticationMethod Modifier and Type Method Description CreateInstanceRequestBodyCreateInstanceRequestBody. authenticationMethod(AuthenticationMethod authenticationMethod)authenticationMethod.voidCreateInstanceRequestBody. setAuthenticationMethod(AuthenticationMethod authenticationMethod)setAuthenticationMethod.
-