Uses of Class
com.docusign.webforms.model.SendOption
-
Packages that use SendOption Package Description com.docusign.webforms.model -
-
Uses of SendOption in com.docusign.webforms.model
Methods in com.docusign.webforms.model that return SendOption Modifier and Type Method Description static SendOptionSendOption. fromValue(String value)SendOptionCreateInstanceRequestBody. getSendOption()Get sendOption.static SendOptionSendOption. valueOf(String name)Returns the enum constant of this type with the specified name.static SendOption[]SendOption. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.docusign.webforms.model with parameters of type SendOption Modifier and Type Method Description CreateInstanceRequestBodyCreateInstanceRequestBody. sendOption(SendOption sendOption)sendOption.voidCreateInstanceRequestBody. setSendOption(SendOption sendOption)setSendOption.
-