Uses of Class
com.docusign.webforms.model.WebFormSource
-
Packages that use WebFormSource Package Description com.docusign.webforms.model -
-
Uses of WebFormSource in com.docusign.webforms.model
Methods in com.docusign.webforms.model that return WebFormSource Modifier and Type Method Description static WebFormSourceWebFormSource. fromValue(String value)WebFormSourceWebFormMetadata. getSource()The source from which the webform is created.static WebFormSourceWebFormSource. valueOf(String name)Returns the enum constant of this type with the specified name.static WebFormSource[]WebFormSource. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.docusign.webforms.model with parameters of type WebFormSource Modifier and Type Method Description voidWebFormMetadata. setSource(WebFormSource source)setSource.WebFormMetadataWebFormMetadata. source(WebFormSource source)source.
-