Uses of Class
com.docusign.webforms.model.WebFormState
-
Packages that use WebFormState Package Description com.docusign.webforms.model -
-
Uses of WebFormState in com.docusign.webforms.model
Methods in com.docusign.webforms.model that return WebFormState Modifier and Type Method Description static WebFormStateWebFormState. fromValue(String value)WebFormStateWebFormSummary. getFormState()Get formState.static WebFormStateWebFormState. valueOf(String name)Returns the enum constant of this type with the specified name.static WebFormState[]WebFormState. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in com.docusign.webforms.model with parameters of type WebFormState Modifier and Type Method Description WebFormSummaryWebFormSummary. formState(WebFormState formState)formState.voidWebFormSummary. setFormState(WebFormState formState)setFormState.
-