| CreateInstanceRequestBody |
Request body containing properties that will be used to create instance..
|
| CreateInstanceRequestBodyRecipients |
CreateInstanceRequestBodyRecipients.
|
| HttpError |
An error occurred while processing a request.
|
| HttpSuccess |
A simple response indicating success when no extra data is needed.
|
| PhoneNumber |
Phone number of the user..
|
| Tags |
List of tags provided by the user with each request.
|
| TemplateProperties |
Information about a DocuSign template that will be used to seed a web form..
|
| UpdateInstanceRequestBody |
Request body containing properties that needs to be updated..
|
| WebForm |
An object that fully describes an instance of a form.
|
| WebFormComponent |
Each component type contains additional properties.
|
| WebFormComponentsMap |
The components map for the web form.
|
| WebFormContent |
Container for the components map used during configuration and data collection.
|
| WebFormInstance |
An object that contains the Web Form Instance required to render it and its metadata such as
created by, created time.
|
| WebFormInstanceEnvelopes |
WebFormInstanceEnvelopes.
|
| WebFormInstanceList |
A list of web form instance items..
|
| WebFormInstanceMetadata |
Web Form Instance metadata containing information like created by, created time, etc..
|
| WebFormInstanceRecipients |
WebFormInstanceRecipients.
|
| WebFormMetadata |
Form metadata.
|
| WebFormProperties |
General information about the web form that is consistent across versions.
|
| WebFormPublishedNames |
A collection of the published component name and its corresponding type.
|
| WebFormSummary |
An object that summarizes an instance of a form that can be used to display a listing.
|
| WebFormSummaryList |
A list of web form summary items..
|
| WebFormUserInfo |
Information about a DocuSign system user.
|
| WebFormValues |
Key-value pairs (where key is the component name and value is the form value) used to create a
form instance.
|