Package com.docusign.webforms.api
Class FormManagementApi
- java.lang.Object
-
- com.docusign.webforms.api.FormManagementApi
-
public class FormManagementApi extends Object
FormManagementApi class.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description classFormManagementApi.GetFormOptionsGetFormOptions Class.classFormManagementApi.ListFormsOptionsListFormsOptions Class.
-
Constructor Summary
Constructors Constructor Description FormManagementApi()FormManagementApi.FormManagementApi(ApiClient apiClient)FormManagementApi.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description ApiClientgetApiClient()getApiClient Method.WebFormgetForm(String accountId, String formId)Get Form.WebFormgetForm(String accountId, String formId, FormManagementApi.GetFormOptions options)Get Form.ApiResponse<WebForm>getFormWithHttpInfo(String accountId, String formId, FormManagementApi.GetFormOptions options)Get Form Retrieves form information filter by form id and state.WebFormSummaryListlistForms(String accountId)List Forms.WebFormSummaryListlistForms(String accountId, FormManagementApi.ListFormsOptions options)List Forms.ApiResponse<WebFormSummaryList>listFormsWithHttpInfo(String accountId, FormManagementApi.ListFormsOptions options)List Forms List all the forms for the active user that can be in an active or draft statevoidsetApiClient(ApiClient apiClient)setApiClient Method.
-
-
-
Constructor Detail
-
FormManagementApi
public FormManagementApi()
FormManagementApi.
-
FormManagementApi
public FormManagementApi(ApiClient apiClient)
FormManagementApi.
-
-
Method Detail
-
getApiClient
public ApiClient getApiClient()
getApiClient Method.- Returns:
- ApiClient
-
setApiClient
public void setApiClient(ApiClient apiClient)
setApiClient Method.
-
getForm
public WebForm getForm(String accountId, String formId) throws ApiException
Get Form. Retrieves form information filter by form id and state. The `state` parameter is optional and can accept value from `draft, active`.- Parameters:
accountId- Account identifier in which the web form resides (required)formId- Unique identifier for a web form that is consistent for it's lifetime (required)- Returns:
- WebForm
- Throws:
ApiException
-
getForm
public WebForm getForm(String accountId, String formId, FormManagementApi.GetFormOptions options) throws ApiException
Get Form. Retrieves form information filter by form id and state. The `state` parameter is optional and can accept value from `draft, active`.- Parameters:
accountId- Account identifier in which the web form resides (required)formId- Unique identifier for a web form that is consistent for it's lifetime (required)options- for modifying the method behavior.- Returns:
- WebForm
- Throws:
ApiException- if fails to make API call
-
getFormWithHttpInfo
public ApiResponse<WebForm> getFormWithHttpInfo(String accountId, String formId, FormManagementApi.GetFormOptions options) throws ApiException
Get Form Retrieves form information filter by form id and state. The `state` parameter is optional and can accept value from `draft, active`.- Parameters:
accountId- Account identifier in which the web form resides (required)formId- Unique identifier for a web form that is consistent for it's lifetime (required)options- for modifying the method behavior.- Returns:
- WebForm
- Throws:
ApiException- if fails to make API call
-
listForms
public WebFormSummaryList listForms(String accountId) throws ApiException
List Forms. List all the forms for the active user that can be in an active or draft state- Parameters:
accountId- Account identifier in which the webform resides (required)- Returns:
- WebFormSummaryList
- Throws:
ApiException
-
listForms
public WebFormSummaryList listForms(String accountId, FormManagementApi.ListFormsOptions options) throws ApiException
List Forms. List all the forms for the active user that can be in an active or draft state- Parameters:
accountId- Account identifier in which the webform resides (required)options- for modifying the method behavior.- Returns:
- WebFormSummaryList
- Throws:
ApiException- if fails to make API call
-
listFormsWithHttpInfo
public ApiResponse<WebFormSummaryList> listFormsWithHttpInfo(String accountId, FormManagementApi.ListFormsOptions options) throws ApiException
List Forms List all the forms for the active user that can be in an active or draft state- Parameters:
accountId- Account identifier in which the webform resides (required)options- for modifying the method behavior.- Returns:
- WebFormSummaryList
- Throws:
ApiException- if fails to make API call
-
-