Package com.docusign.webforms.model
Class HttpError
- java.lang.Object
-
- com.docusign.webforms.model.HttpError
-
- All Implemented Interfaces:
Serializable
public class HttpError extends Object implements Serializable
An error occurred while processing a request. Source - https://www.baeldung.com/rest-api-error-handling-best-practices.- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description HttpError()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object o)Compares objects.HttpErrorerrorCode(String errorCode)errorCode.StringgetErrorCode()A granular, human and computer readable code indicating more deeply what error occurred..StringgetMessage()A human-readable description of the error, meant for developers to store for their review..inthashCode()Returns the HashCode.HttpErrormessage(String message)message.voidsetErrorCode(String errorCode)setErrorCode.voidsetMessage(String message)setMessage.StringtoString()Converts the given object to string.
-
-
-
Method Detail
-
getErrorCode
public String getErrorCode()
A granular, human and computer readable code indicating more deeply what error occurred..- Returns:
- errorCode
-
setErrorCode
public void setErrorCode(String errorCode)
setErrorCode.
-
getMessage
public String getMessage()
A human-readable description of the error, meant for developers to store for their review..- Returns:
- message
-
setMessage
public void setMessage(String message)
setMessage.
-
equals
public boolean equals(Object o)
Compares objects.
-
-