Package com.docusign.webforms.model
Enum Source
- java.lang.Object
-
- java.lang.Enum<Source>
-
- com.docusign.webforms.model.Source
-
- All Implemented Interfaces:
Serializable,Comparable<Source>
public enum Source extends Enum<Source>
The method through which form instance is created.
-
-
Enum Constant Summary
Enum Constants Enum Constant Description API_EMBEDDEDAPI_REMOTEPUBLIC_URLUI_REMOTE
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static SourcefromValue(String value)StringgetValue()StringtoString()static SourcevalueOf(String name)Returns the enum constant of this type with the specified name.static Source[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Method Detail
-
values
public static Source[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (Source c : Source.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static Source valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getValue
public String getValue()
-
-