Package com.docusign.webforms.model
Class WebFormMetadata
- java.lang.Object
-
- com.docusign.webforms.model.WebFormMetadata
-
- All Implemented Interfaces:
Serializable
public class WebFormMetadata extends Object implements Serializable
Form metadata.- See Also:
- Serialized Form
-
-
Constructor Summary
Constructors Constructor Description WebFormMetadata()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description WebFormMetadataarchivedDateTime(String archivedDateTime)archivedDateTime.WebFormMetadatacreatedDateTime(String createdDateTime)createdDateTime.booleanequals(Object o)Compares objects.WebFormMetadataformContentModifiedBy(WebFormUserInfo formContentModifiedBy)formContentModifiedBy.WebFormMetadataformContentModifiedDateTime(String formContentModifiedDateTime)formContentModifiedDateTime.WebFormMetadataformPropertiesModifiedBy(WebFormUserInfo formPropertiesModifiedBy)formPropertiesModifiedBy.WebFormMetadataformPropertiesModifiedDateTime(String formPropertiesModifiedDateTime)formPropertiesModifiedDateTime.StringgetArchivedDateTime()The last time the web form was archived.StringgetCreatedDateTime()Track the time the web form was created.WebFormUserInfogetFormContentModifiedBy()Track the user that last modified the form content.StringgetFormContentModifiedDateTime()Track the last time web form content changed..WebFormUserInfogetFormPropertiesModifiedBy()Track the user that last modified the form properties.StringgetFormPropertiesModifiedDateTime()Track the last time the form properties changed..WebFormUserInfogetLastDisabledBy()Track the user that last unpublished an active version.StringgetLastDisabledDateTime()Track the last time the form was disabled.WebFormUserInfogetLastEnabledBy()Track the user that last unpublished an active version.StringgetLastEnabledDateTime()Track the last time the form was enabled.WebFormUserInfogetLastModifiedBy()Track the user that last modified anything related to the form.StringgetLastModifiedDateTime()The last time anything was modified on the form.WebFormUserInfogetLastPublishedBy()Track the user that last published a draft version to active.StringgetLastPublishedDateTime()Track the last time a draft version was published to active.StringgetLastSenderConsentDateTime()Track the last time a user added their consent for the form..WebFormUserInfogetOwner()The user that created the form or has been transferred ownership.Map<String,WebFormComponentType>getPublishedComponentNames()A dictionary containing the mapping of component names to their respective component types for all the published components..StringgetPublishedSlug()The public friendly slug that is used to access the form from the player.WebFormUserInfogetSender()The user that has added their consent to the form for sending actions.WebFormSourcegetSource()The source from which the webform is created.StringgetSourceFormId()The source form id from which the webform is created..WebFormTypegetType()Represents webform type.inthashCode()Returns the HashCode.WebFormMetadatalastDisabledBy(WebFormUserInfo lastDisabledBy)lastDisabledBy.WebFormMetadatalastDisabledDateTime(String lastDisabledDateTime)lastDisabledDateTime.WebFormMetadatalastEnabledBy(WebFormUserInfo lastEnabledBy)lastEnabledBy.WebFormMetadatalastEnabledDateTime(String lastEnabledDateTime)lastEnabledDateTime.WebFormMetadatalastModifiedBy(WebFormUserInfo lastModifiedBy)lastModifiedBy.WebFormMetadatalastModifiedDateTime(String lastModifiedDateTime)lastModifiedDateTime.WebFormMetadatalastPublishedBy(WebFormUserInfo lastPublishedBy)lastPublishedBy.WebFormMetadatalastPublishedDateTime(String lastPublishedDateTime)lastPublishedDateTime.WebFormMetadatalastSenderConsentDateTime(String lastSenderConsentDateTime)lastSenderConsentDateTime.WebFormMetadataowner(WebFormUserInfo owner)owner.WebFormMetadatapublishedComponentNames(Map<String,WebFormComponentType> publishedComponentNames)publishedComponentNames.WebFormMetadatapublishedSlug(String publishedSlug)publishedSlug.WebFormMetadataputPublishedComponentNamesItem(String key, WebFormComponentType publishedComponentNamesItem)putPublishedComponentNamesItem.WebFormMetadatasender(WebFormUserInfo sender)sender.voidsetArchivedDateTime(String archivedDateTime)setArchivedDateTime.voidsetCreatedDateTime(String createdDateTime)setCreatedDateTime.voidsetFormContentModifiedBy(WebFormUserInfo formContentModifiedBy)setFormContentModifiedBy.voidsetFormContentModifiedDateTime(String formContentModifiedDateTime)setFormContentModifiedDateTime.voidsetFormPropertiesModifiedBy(WebFormUserInfo formPropertiesModifiedBy)setFormPropertiesModifiedBy.voidsetFormPropertiesModifiedDateTime(String formPropertiesModifiedDateTime)setFormPropertiesModifiedDateTime.voidsetLastDisabledBy(WebFormUserInfo lastDisabledBy)setLastDisabledBy.voidsetLastDisabledDateTime(String lastDisabledDateTime)setLastDisabledDateTime.voidsetLastEnabledBy(WebFormUserInfo lastEnabledBy)setLastEnabledBy.voidsetLastEnabledDateTime(String lastEnabledDateTime)setLastEnabledDateTime.voidsetLastModifiedBy(WebFormUserInfo lastModifiedBy)setLastModifiedBy.voidsetLastModifiedDateTime(String lastModifiedDateTime)setLastModifiedDateTime.voidsetLastPublishedBy(WebFormUserInfo lastPublishedBy)setLastPublishedBy.voidsetLastPublishedDateTime(String lastPublishedDateTime)setLastPublishedDateTime.voidsetLastSenderConsentDateTime(String lastSenderConsentDateTime)setLastSenderConsentDateTime.voidsetOwner(WebFormUserInfo owner)setOwner.voidsetPublishedComponentNames(Map<String,WebFormComponentType> publishedComponentNames)setPublishedComponentNames.voidsetPublishedSlug(String publishedSlug)setPublishedSlug.voidsetSender(WebFormUserInfo sender)setSender.voidsetSource(WebFormSource source)setSource.voidsetSourceFormId(String sourceFormId)setSourceFormId.voidsetType(WebFormType type)setType.WebFormMetadatasource(WebFormSource source)source.WebFormMetadatasourceFormId(String sourceFormId)sourceFormId.StringtoString()Converts the given object to string.WebFormMetadatatype(WebFormType type)type.
-
-
-
Method Detail
-
source
public WebFormMetadata source(WebFormSource source)
source.- Returns:
- WebFormMetadata
-
getSource
public WebFormSource getSource()
The source from which the webform is created. Accepted values are [templates, blank, form].- Returns:
- source
-
setSource
public void setSource(WebFormSource source)
setSource.
-
type
public WebFormMetadata type(WebFormType type)
type.- Returns:
- WebFormMetadata
-
getType
public WebFormType getType()
Represents webform type. Possible values are [standalone, hasEsignTemplate].- Returns:
- type
-
setType
public void setType(WebFormType type)
setType.
-
sourceFormId
public WebFormMetadata sourceFormId(String sourceFormId)
sourceFormId.- Returns:
- WebFormMetadata
-
getSourceFormId
public String getSourceFormId()
The source form id from which the webform is created..- Returns:
- sourceFormId
-
setSourceFormId
public void setSourceFormId(String sourceFormId)
setSourceFormId.
-
owner
public WebFormMetadata owner(WebFormUserInfo owner)
owner.- Returns:
- WebFormMetadata
-
getOwner
public WebFormUserInfo getOwner()
The user that created the form or has been transferred ownership.- Returns:
- owner
-
setOwner
public void setOwner(WebFormUserInfo owner)
setOwner.
-
sender
public WebFormMetadata sender(WebFormUserInfo sender)
sender.- Returns:
- WebFormMetadata
-
getSender
public WebFormUserInfo getSender()
The user that has added their consent to the form for sending actions.- Returns:
- sender
-
setSender
public void setSender(WebFormUserInfo sender)
setSender.
-
lastModifiedBy
public WebFormMetadata lastModifiedBy(WebFormUserInfo lastModifiedBy)
lastModifiedBy.- Returns:
- WebFormMetadata
-
getLastModifiedBy
public WebFormUserInfo getLastModifiedBy()
Track the user that last modified anything related to the form.- Returns:
- lastModifiedBy
-
setLastModifiedBy
public void setLastModifiedBy(WebFormUserInfo lastModifiedBy)
setLastModifiedBy.
-
formContentModifiedBy
public WebFormMetadata formContentModifiedBy(WebFormUserInfo formContentModifiedBy)
formContentModifiedBy.- Returns:
- WebFormMetadata
-
getFormContentModifiedBy
public WebFormUserInfo getFormContentModifiedBy()
Track the user that last modified the form content.- Returns:
- formContentModifiedBy
-
setFormContentModifiedBy
public void setFormContentModifiedBy(WebFormUserInfo formContentModifiedBy)
setFormContentModifiedBy.
-
formPropertiesModifiedBy
public WebFormMetadata formPropertiesModifiedBy(WebFormUserInfo formPropertiesModifiedBy)
formPropertiesModifiedBy.- Returns:
- WebFormMetadata
-
getFormPropertiesModifiedBy
public WebFormUserInfo getFormPropertiesModifiedBy()
Track the user that last modified the form properties.- Returns:
- formPropertiesModifiedBy
-
setFormPropertiesModifiedBy
public void setFormPropertiesModifiedBy(WebFormUserInfo formPropertiesModifiedBy)
setFormPropertiesModifiedBy.
-
lastPublishedBy
public WebFormMetadata lastPublishedBy(WebFormUserInfo lastPublishedBy)
lastPublishedBy.- Returns:
- WebFormMetadata
-
getLastPublishedBy
public WebFormUserInfo getLastPublishedBy()
Track the user that last published a draft version to active.- Returns:
- lastPublishedBy
-
setLastPublishedBy
public void setLastPublishedBy(WebFormUserInfo lastPublishedBy)
setLastPublishedBy.
-
lastEnabledBy
public WebFormMetadata lastEnabledBy(WebFormUserInfo lastEnabledBy)
lastEnabledBy.- Returns:
- WebFormMetadata
-
getLastEnabledBy
public WebFormUserInfo getLastEnabledBy()
Track the user that last unpublished an active version.- Returns:
- lastEnabledBy
-
setLastEnabledBy
public void setLastEnabledBy(WebFormUserInfo lastEnabledBy)
setLastEnabledBy.
-
lastDisabledBy
public WebFormMetadata lastDisabledBy(WebFormUserInfo lastDisabledBy)
lastDisabledBy.- Returns:
- WebFormMetadata
-
getLastDisabledBy
public WebFormUserInfo getLastDisabledBy()
Track the user that last unpublished an active version.- Returns:
- lastDisabledBy
-
setLastDisabledBy
public void setLastDisabledBy(WebFormUserInfo lastDisabledBy)
setLastDisabledBy.
-
archivedDateTime
public WebFormMetadata archivedDateTime(String archivedDateTime)
archivedDateTime.- Returns:
- WebFormMetadata
-
getArchivedDateTime
public String getArchivedDateTime()
The last time the web form was archived.- Returns:
- archivedDateTime
-
setArchivedDateTime
public void setArchivedDateTime(String archivedDateTime)
setArchivedDateTime.
-
createdDateTime
public WebFormMetadata createdDateTime(String createdDateTime)
createdDateTime.- Returns:
- WebFormMetadata
-
getCreatedDateTime
public String getCreatedDateTime()
Track the time the web form was created.- Returns:
- createdDateTime
-
setCreatedDateTime
public void setCreatedDateTime(String createdDateTime)
setCreatedDateTime.
-
lastModifiedDateTime
public WebFormMetadata lastModifiedDateTime(String lastModifiedDateTime)
lastModifiedDateTime.- Returns:
- WebFormMetadata
-
getLastModifiedDateTime
public String getLastModifiedDateTime()
The last time anything was modified on the form.- Returns:
- lastModifiedDateTime
-
setLastModifiedDateTime
public void setLastModifiedDateTime(String lastModifiedDateTime)
setLastModifiedDateTime.
-
formContentModifiedDateTime
public WebFormMetadata formContentModifiedDateTime(String formContentModifiedDateTime)
formContentModifiedDateTime.- Returns:
- WebFormMetadata
-
getFormContentModifiedDateTime
public String getFormContentModifiedDateTime()
Track the last time web form content changed..- Returns:
- formContentModifiedDateTime
-
setFormContentModifiedDateTime
public void setFormContentModifiedDateTime(String formContentModifiedDateTime)
setFormContentModifiedDateTime.
-
formPropertiesModifiedDateTime
public WebFormMetadata formPropertiesModifiedDateTime(String formPropertiesModifiedDateTime)
formPropertiesModifiedDateTime.- Returns:
- WebFormMetadata
-
getFormPropertiesModifiedDateTime
public String getFormPropertiesModifiedDateTime()
Track the last time the form properties changed..- Returns:
- formPropertiesModifiedDateTime
-
setFormPropertiesModifiedDateTime
public void setFormPropertiesModifiedDateTime(String formPropertiesModifiedDateTime)
setFormPropertiesModifiedDateTime.
-
lastPublishedDateTime
public WebFormMetadata lastPublishedDateTime(String lastPublishedDateTime)
lastPublishedDateTime.- Returns:
- WebFormMetadata
-
getLastPublishedDateTime
public String getLastPublishedDateTime()
Track the last time a draft version was published to active.- Returns:
- lastPublishedDateTime
-
setLastPublishedDateTime
public void setLastPublishedDateTime(String lastPublishedDateTime)
setLastPublishedDateTime.
-
lastEnabledDateTime
public WebFormMetadata lastEnabledDateTime(String lastEnabledDateTime)
lastEnabledDateTime.- Returns:
- WebFormMetadata
-
getLastEnabledDateTime
public String getLastEnabledDateTime()
Track the last time the form was enabled.- Returns:
- lastEnabledDateTime
-
setLastEnabledDateTime
public void setLastEnabledDateTime(String lastEnabledDateTime)
setLastEnabledDateTime.
-
lastDisabledDateTime
public WebFormMetadata lastDisabledDateTime(String lastDisabledDateTime)
lastDisabledDateTime.- Returns:
- WebFormMetadata
-
getLastDisabledDateTime
public String getLastDisabledDateTime()
Track the last time the form was disabled.- Returns:
- lastDisabledDateTime
-
setLastDisabledDateTime
public void setLastDisabledDateTime(String lastDisabledDateTime)
setLastDisabledDateTime.
-
lastSenderConsentDateTime
public WebFormMetadata lastSenderConsentDateTime(String lastSenderConsentDateTime)
lastSenderConsentDateTime.- Returns:
- WebFormMetadata
-
getLastSenderConsentDateTime
public String getLastSenderConsentDateTime()
Track the last time a user added their consent for the form..- Returns:
- lastSenderConsentDateTime
-
setLastSenderConsentDateTime
public void setLastSenderConsentDateTime(String lastSenderConsentDateTime)
setLastSenderConsentDateTime.
-
publishedSlug
public WebFormMetadata publishedSlug(String publishedSlug)
publishedSlug.- Returns:
- WebFormMetadata
-
getPublishedSlug
public String getPublishedSlug()
The public friendly slug that is used to access the form from the player.- Returns:
- publishedSlug
-
setPublishedSlug
public void setPublishedSlug(String publishedSlug)
setPublishedSlug.
-
publishedComponentNames
public WebFormMetadata publishedComponentNames(Map<String,WebFormComponentType> publishedComponentNames)
publishedComponentNames.- Returns:
- WebFormMetadata
-
putPublishedComponentNamesItem
public WebFormMetadata putPublishedComponentNamesItem(String key, WebFormComponentType publishedComponentNamesItem)
putPublishedComponentNamesItem.- Returns:
- WebFormMetadata
-
getPublishedComponentNames
public Map<String,WebFormComponentType> getPublishedComponentNames()
A dictionary containing the mapping of component names to their respective component types for all the published components..- Returns:
- publishedComponentNames
-
setPublishedComponentNames
public void setPublishedComponentNames(Map<String,WebFormComponentType> publishedComponentNames)
setPublishedComponentNames.
-
equals
public boolean equals(Object o)
Compares objects.
-
-